aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorfriendica <info@friendica.com>2014-11-18 16:58:36 -0800
committerfriendica <info@friendica.com>2014-11-18 16:58:36 -0800
commit11f0b45a9015a717e6e0da1bfd5a1c61381d64ed (patch)
tree073808e68c0baa3cbdad511db49f4bc9792acfb4
parent38d50cabd4b3db859c5ac33f02760b1b00a993e5 (diff)
downloadvolse-hubzilla-11f0b45a9015a717e6e0da1bfd5a1c61381d64ed.tar.gz
volse-hubzilla-11f0b45a9015a717e6e0da1bfd5a1c61381d64ed.tar.bz2
volse-hubzilla-11f0b45a9015a717e6e0da1bfd5a1c61381d64ed.zip
blog mode - turn the comment link into a button and group with the likes/dislikes
-rwxr-xr-xmod/like.php18
-rwxr-xr-xview/tpl/conv_list.tpl9
2 files changed, 11 insertions, 16 deletions
diff --git a/view/tpl/conv_list.tpl b/view/tpl/conv_list.tpl
index b9a966e93..444734f48 100755
--- a/view/tpl/conv_list.tpl
+++ b/view/tpl/conv_list.tpl
@@ -104,7 +104,12 @@
</ul>
</div>
<div id="like-rotator-{{$item.id}}" class="like-rotator"></div>
- <div class="wall-item-tools-left{{if $item.like_count && $item.dislike_count}} btn-group{{/if}}">
+ <div class="wall-item-tools-left btn-group">
+
+
+ <div class="wall-item-list-comments btn-group"><button class="btn btn-default btn-sm" onclick="window.location.href='{{$item.llink}}'; return false;">{{$item.comment_count_txt}}{{if $item.unseen_comments}}
+<span class="unseen-wall-indicator-{{$item.id}}">, {{$item.list_unseen_txt}}{{/if}}</span></button></div>{{if $item.unseen_comments}}<div class="unseen-wall-indicator-{{$item.id}} btn-group"><button class="btn btn-default btn-sm" title="{{$item.markseen}}" onclick="markItemRead({{$item.id}}); return false;"><i class="icon-check"></i></div>{{/if}}
+
{{if $item.like_count}}
<div class="btn-group">
<button type="button" class="btn btn-default btn-sm wall-item-like dropdown-toggle" data-toggle="dropdown" id="wall-item-like-{{$item.id}}">{{$item.like_count}} {{$item.like_button_label}}</button>
@@ -164,8 +169,6 @@
{{/if}}
</div>
<div class="clear"></div>
- <div class="wall-item-list-comments"><a href="{{$item.llink}}">{{$item.comment_count_txt}}{{if $item.unseen_comments}}
-<span class="unseen-wall-indicator-{{$item.id}}">, {{$item.list_unseen_txt}}{{/if}}</span></a>{{if $item.unseen_comments}}<span class="unseen-wall-indicator-{{$item.id}}">&nbsp;&nbsp;&nbsp;<button class="btn btn-default" title="{{$item.markseen}}" onclick="markItemRead({{$item.id}}); return false;"><i class="icon-check"></i></span>{{/if}}</div>
</div>
<div class="wall-item-wrapper-end"></div>
<div class="wall-item-outside-wrapper-end {{$item.indent}}" ></div>
diff --git a/mod/like.php b/mod/like.php
index b56611197..04a2b43cd 100755
--- a/mod/like.php
+++ b/mod/like.php
@@ -263,26 +263,18 @@ function like_content(&$a) {
else
killme();
-
- $r = q("SELECT * FROM item WHERE verb = '%s' AND item_restrict = 0
+ $r = q("SELECT id FROM item WHERE verb = '%s' AND item_restrict = 0
AND author_xchan = '%s' AND ( parent = %d OR thr_parent = '%s') LIMIT 1",
dbesc($activity),
dbesc($observer['xchan_hash']),
intval($item_id),
dbesc($item['mid'])
);
- if($r) {
- $like_item = $r[0];
-
- // Already liked/disliked it, delete it
- $r = q("UPDATE item SET item_restrict = ( item_restrict & ~%d ), changed = '%s' WHERE id = %d",
- intval(ITEM_DELETED),
- dbesc(datetime_convert()),
- intval($like_item['id'])
- );
-
- proc_run('php',"include/notifier.php","like",$like_item['id']);
+ if($r) {
+ // already liked it. Drop that item.
+ require_once('include/items.php');
+ drop_item($r[0]['id'],false,DROPITEM_PHASE1);
return;
}